@@ -6,7 +6,6 @@ use Minion::Job;
 use Minion::Worker;
 use Mojo::Loader 'load_class';
 use Mojo::Server;
-use Mojo::URL;
 use Scalar::Util 'weaken';
 
 has app => sub { Mojo::Server->new->build_app('Mojo::HelloWorld') };
@@ -16,7 +15,7 @@ has missing_after => 1800;
 has remove_after  => 172800;
 has tasks         => sub { {} };
 
-our $VERSION = '5.03';
+our $VERSION = '5.04';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -427,6 +426,14 @@ Number of jobs in C<active> state.
 
 Number of workers that are currently processing a job.
 
+=item delayed_jobs
+
+  delayed_jobs => 100
+
+Number of jobs in C<inactive> state that are scheduled to run at specific time
+in the future. Note that this field is EXPERIMENTAL and might change without
+warning!
+
 =item failed_jobs
 
   failed_jobs => 100
