@@ -3,7 +3,7 @@ use Mojo::Base 'Minion::Backend';
 
 use Carp 'croak';
 use Mojo::IOLoop;
-use Mojo::Pg;
+use Mojo::Pg 2.18;
 use Sys::Hostname 'hostname';
 
 has 'pg';
@@ -149,6 +149,9 @@ sub stats {
 
   my $stats = $self->pg->db->query(
     "select state::text || '_jobs', count(state) from minion_jobs group by state
+     union all
+     select 'delayed_jobs', count(*) from minion_jobs
+     where state = 'inactive' and delayed > now()
      union all
      select 'inactive_workers', count(*) from minion_workers
      union all
@@ -316,7 +319,8 @@ These options are currently available:
 
   attempts => 25
 
-Number of times performing this job will be attempted, defaults to C<1>.
+Number of times performing this job will be attempted, with a delay based on
+L<Minion/"backoff"> after the first attempt, defaults to C<1>.
 
 =item delay
 
@@ -384,25 +388,25 @@ Job arguments.
 
   attempts => 25
 
-Number of times performing this job will be attempted, defaults to C<1>.
+Number of times performing this job will be attempted.
 
 =item created
 
   created => 784111777
 
-Time job was created.
+Epoch time job was created.
 
 =item delayed
 
   delayed => 784111777
 
-Time job was delayed to.
+Epoch time job was delayed to.
 
 =item finished
 
   finished => 784111777
 
-Time job was finished.
+Epoch time job was finished.
 
 =item priority
 
@@ -426,7 +430,7 @@ Job result.
 
   retried => 784111777
 
-Time job has been retried.
+Epoch time job has been retried.
 
 =item retries
 
@@ -438,7 +442,7 @@ Number of times job has been retried.
 
   started => 784111777
 
-Time job was started.
+Epoch time job was started.
 
 =item state
 
@@ -576,6 +580,14 @@ Number of jobs in C<active> state.
 
 Number of workers that are currently processing a job.
 
+=item delayed_jobs
+
+  delayed_jobs => 100
+
+Number of jobs in C<inactive> state that are scheduled to run at specific time
+in the future. Note that this field is EXPERIMENTAL and might change without
+warning!
+
 =item failed_jobs
 
   failed_jobs => 100
@@ -637,7 +649,7 @@ Ids of jobs the worker is currently processing.
 
   notified => 784111777
 
-Last time worker sent a heartbeat.
+Epoch time worker sent the last heartbeat.
 
 =item pid
 
@@ -649,7 +661,7 @@ Process id of worker.
 
   started => 784111777
 
-Time worker was started.
+Epoch time worker was started.
 
 =back
 
